@@ -11,7 +11,8 @@ from typing import Dict
 from typing import List
 from typing import Optional
 
-from falocalrepo_database import FADatabase, FADatabaseTable
+from falocalrepo_database import FADatabase
+from falocalrepo_database import FADatabaseTable
 from falocalrepo_database import tiered_path
 from flask import Flask
 from flask import abort
@@ -189,17 +190,16 @@ def search(table: str = "submissions"):
         if "offset" in params:
             del params["offset"]
 
-        if (last_search["table"], last_search["params"]) != (table, params):
+        if (last_search["table"], last_search["params"], last_search["order"]) != (table, params, order):
             last_search["table"] = table
             last_search["params"] = deepcopy(params)
+            last_search["order"] = deepcopy(order)
             db_table: FADatabaseTable = db[table]
             if "author" in params:
                 params["replace(author, '_', '')"] = list(map(clean_username, params["author"]))
                 del params["author"]
-            if list(params.keys()) == ["order"]:
-                last_search["results"] = list(db_table)
-            else:
-                last_search["results"] = list(db_table.cursor_to_dict(db_table.select(params, like=True, order=order)))
+            last_search["results"] = list(
+                db_table.cursor_to_dict(db_table.select(params, columns, like=True, order=order), columns))
 
         return render_template(
             "search_results.html",
